@@ -494,7 +494,7 @@ class CLI(object):
                     # If the host path uses the $volume variable, we need to replace it
                     # with the actual volume path.
                     if "$volume" in host:
-                        host = host.replace("$volume", volume)
+                        host = host.replace("$volume", str(volume))
 
                     # If the host path uses the $model variable, we need to replace it
                     # with the actual model-specific path.
